@@ -1,5 +1,5 @@
 import typer
-import commands as flashyfly
+import commands 
 
 app = typer.Typer(context_settings={"help_option_names": ["-h", "--help"]}, add_help_option=True, no_args_is_help=True)
 app_project = typer.Typer(context_settings={"help_option_names": ["-h", "--help"]}, add_help_option=True, no_args_is_help=True)
@@ -11,7 +11,7 @@ def init():
     Initialize project directory tree.
     """
     try: 
-        flashyfly.init()
+        commands.init()
         typer.echo('Project directory tree initialized.')
     except: 
         typer.echo('Project directory tree already initialized.')
@@ -21,7 +21,7 @@ def build():
     """
     Build binaries according to manifest file.
     """
-    flashyfly.builder()
+    commands.builder()
     typer.echo('Building finished.')
 
 @app.command()
@@ -29,7 +29,7 @@ def flash():
     """
     Flash binaries according to availability.
     """
-    flashyfly.flasher()
+    commands.flasher()
     typer.echo('Flashing finished.')
 
 def main(): # if __name__ == "__main__":
